Structs
- Delimiter
- Represents a delimiter that will be used to process the input value into segments
- Extractor
- A struct to be used with the
ProcessorBuilderto select values from the original string value before segmentation - File
Input - Represents file path input in
InputType - Format
- Represents the provided format string and all the detected format patterns
- Processor
Builder - A
ProcessorBuilderis used to configure the renaming process and producesRenamedwhen processing is activated - Replacer
- Represents a
Regexthat is used to replace matches with a provided substitution - Selector
- Represents a
Regexthat is used to find a single matching segment - Text
Input - Represents plain text input in
InputType - Trim
- Represents a
Stringto be trimmed from a value based on the provided configuration
Enums
- Delimiter
Type - USed with
Delimiterto indicate what type of processing should be used - Error
- Errors returned by pass-it-on-command-line-client
- Input
Type - Enum used to pass inputs to the
ProcessorBuilder
Traits
- Renamed
- This trait represents that has had the renaming process completed