pub struct ProcessorBuilder { /* private fields */ }Expand description
A ProcessorBuilder is used to configure the renaming process and produces Renamed when processing is activated
Implementations
Sourceimpl ProcessorBuilder
impl ProcessorBuilder
Sourcepub fn new(format: Format) -> Self
pub fn new(format: Format) -> Self
Constructs new ProcessorBuilder
Sourcepub fn delimiter(self, delimiter: Delimiter) -> Self
pub fn delimiter(self, delimiter: Delimiter) -> Self
Appends a single Delimiter item to the existing configuration
Sourcepub fn delimiters(self, delimiters: Vec<Delimiter>) -> Self
pub fn delimiters(self, delimiters: Vec<Delimiter>) -> Self
Appends multiple Delimiter items to the existing configuration
Sourcepub fn extractor(self, extractor: Extractor) -> Self
pub fn extractor(self, extractor: Extractor) -> Self
Appends a single Extractor item to the existing configuration
Sourcepub fn extractors(self, extractors: Vec<Extractor>) -> Self
pub fn extractors(self, extractors: Vec<Extractor>) -> Self
Appends multiple Extractor items to the existing configuration
Sourcepub fn input(self, input: InputType) -> Self
pub fn input(self, input: InputType) -> Self
Appends a single file path to the existing configuration
Sourcepub fn inputs(self, inputs: Vec<InputType>) -> Self
pub fn inputs(self, inputs: Vec<InputType>) -> Self
Appends multiple file paths items to the existing configuration
Sourcepub fn replacer(self, trim: Replacer) -> Self
pub fn replacer(self, trim: Replacer) -> Self
Appends a single Replacer item to the existing configuration
Sourcepub fn replacers(self, trims: Vec<Replacer>) -> Self
pub fn replacers(self, trims: Vec<Replacer>) -> Self
Appends multiple Replacer items to the existing configuration
Sourcepub fn selector(self, selector: Selector) -> Self
pub fn selector(self, selector: Selector) -> Self
Appends a single Selector item to the existing configuration
Sourcepub fn selectors(self, selectors: Vec<Selector>) -> Self
pub fn selectors(self, selectors: Vec<Selector>) -> Self
Appends multiple Selector items to the existing configuration
Sourcepub fn trims(self, trims: Vec<Trim>) -> Self
pub fn trims(self, trims: Vec<Trim>) -> Self
Appends multiple Trim items to the existing configuration
Sourcepub fn process(&self) -> Result<Vec<Box<dyn Renamed>>, Error>
pub fn process(&self) -> Result<Vec<Box<dyn Renamed>>, Error>
Returns Renamed trait objects based on the ProcessorBuilder configuration for all items
Sourcepub fn process_subset(
&self,
processing_limit: usize,
) -> Result<Vec<Box<dyn Renamed>>, Error>
pub fn process_subset( &self, processing_limit: usize, ) -> Result<Vec<Box<dyn Renamed>>, Error>
Returns Renamed trait objects based on the ProcessorBuilder configuration up to the processing limit provided